/* main.c - Configure cups printer drivers via D-BUS
 *
 * Copyright (C) 2002, 2003  Red Hat Inc.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include <glib.h>
#include <getopt.h>
#include <errno.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <stdio.h>
#include <string.h>

#include "rb-debug.h"
#include "cups-config-daemon.h"

void
print_usage (void)
{
	fprintf (stderr, "\n" "usage : cups-config-daemon [--daemon=yes|no] [--help]\n");
	fprintf (stderr,
		"\n"
		"        --daemon=yes|no    Become a daemon\n"
		"        --help             Show this information and exit\n"
		"\n"
		"cups-config-daemon waits for D-BUS calls when a console user\n"
		"configures a local printer that could not be autodetected.\n"
		"Using the information gathered from the user it then configures\n"
		"the printer with the correct driver.\n"
		"\n");
}

int
main (int argc, char *argv[])
{
	CupsConfigDaemon *confd;
	gboolean become_daemon; 
	become_daemon = TRUE;
	GMainLoop *loop;
	gboolean debug = FALSE;

	/* Parse options */
	while (1)
	{
		int c;
		int option_index = 0;
		const char *opt;

		static struct option options[] = {
			{"daemon",	1, NULL, 0},
			{"help",	0, NULL, 0},
			{"debug",	0, NULL, 0},
			{NULL,		0, NULL, 0}
		};

		c = getopt_long (argc, argv, "", options, &option_index);
		if (c == -1)
			break;

		switch (c)
		{
			case 0:
				opt = options[option_index].name;
				if (strcmp (opt, "help") == 0)
				{
					print_usage ();
					return 0;
				}
				else if (strcmp (opt, "daemon") == 0)
				{
					if (strcmp ("yes", optarg) == 0)
						become_daemon = TRUE;
					else if (strcmp ("no", optarg) == 0)
						become_daemon = FALSE;
					else
					{
						print_usage ();
						return 1;
					}
				}
				else if (strcmp (opt, "debug") == 0)
				{
					debug = TRUE;
				}
				break;

			default:
				print_usage ();
				return 1;
				break;
		}
	}

	rb_debug_init (debug);

	if (become_daemon)
	{
		if (daemon(0, 0) < 0) {
			perror("Couldn't daemon()");
			exit(1);
		}
	}

	g_type_init ();

	confd = cups_config_daemon_new ();

	rb_debug ("Entering main loop");
	loop = g_main_loop_new (NULL, FALSE);
	g_main_loop_run (loop);

	rb_debug ("Cleaning up and exiting");
	g_object_unref (confd);

	return 0;
}
